==> userway_tool-1.0.0.tar.gz: userway_tool/src/Plugin/Block/UserwayWidgetBlock.php <==
<?php

namespace Drupal\userway_tool\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Provides a Userway widget block.
 *
 * @Block( id = "userway_widget_block",
 * admin_label = @Translation("Userway Widget Block"),
 * category = @Translation("Userway")
 * )
 */
class UserwayWidgetBlock extends BlockBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The admin userway configuration.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The current user.
   *
   * @var Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Userway Block.
   *
   * @param array $configuration
   *   The Gleap block configuration.
   * @param mixed $plugin_id
   *   The plugin ID.
   * @param mixed $plugin_definition
   *   The plugin path destination.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param Drupal\Core\Session\AccountInterface $currentUser
   *   The current user.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory, AccountInterface $currentUser, MessengerInterface $messenger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory->get('userway_tool.userway_configuration');
    $this->currentUser = $currentUser;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('current_user'),
      $container->get('messenger'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    if (empty($this->configFactory->get('userway_key')) && ($this->currentUser->hasPermission('administer userway'))) {
      // Generate the URL from the route name
      $url = Url::fromRoute('userway_tool_configuration');

      // Create the link object
      $link = Link::fromTextAndUrl($this->t('here'), $url);

      // Convert the link to a renderable string
      $link = $link->toString();
      // Create the warning message with the link
      $message = $this->t('Please fill out the UserWay key from %link', ['%link' => $link]);

      // Add the warning message
      \Drupal::messenger()->addWarning($message);

      // Return an empty render array since the warning message is displayed separately
      return [];
    }
    else {
      $script = Markup::create('<script src="https://cdn.userway.org/widget.js" data-account=">' . $this->configFactory->get('userway_key') . '"</script>');
    }
    return [
      '#markup' => $script,
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    if ($this->currentUser->hasPermission('view userway widget')) {
      return AccessResult::allowed();
    }
    else {
      return AccessResult::forbidden();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return Cache::mergeContexts(parent::getCacheContexts(), ['route']);
  }

}

==> userway_tool-1.0.1.tar.gz: userway_tool/src/Plugin/Block/UserwayWidgetBlock.php <==
<?php

namespace Drupal\userway_tool\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Provides a Userway widget block.
 *
 * @Block( id = "userway_widget_block",
 * admin_label = @Translation("Userway Widget Block"),
 * category = @Translation("Userway")
 * )
 */
class UserwayWidgetBlock extends BlockBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The admin userway configuration.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The current user.
   *
   * @var Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Userway Block.
   *
   * @param array $configuration
   *   The Gleap block configuration.
   * @param mixed $plugin_id
   *   The plugin ID.
   * @param mixed $plugin_definition
   *   The plugin path destination.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param Drupal\Core\Session\AccountInterface $currentUser
   *   The current user.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory, AccountInterface $currentUser, MessengerInterface $messenger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory->get('userway_tool.userway_configuration');
    $this->currentUser = $currentUser;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('current_user'),
      $container->get('messenger'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    if (empty($this->configFactory->get('userway_key')) && ($this->currentUser->hasPermission('administer userway'))) {
      // Generate the URL from the route name
      $url = Url::fromRoute('userway_tool_configuration');

      // Create the link object
      $link = Link::fromTextAndUrl($this->t('here'), $url);

      // Convert the link to a renderable string
      $link = $link->toString();
      // Create the warning message with the link
      $message = $this->t('Please fill out the UserWay key from %link', ['%link' => $link]);

      // Add the warning message
      \Drupal::messenger()->addWarning($message);

      // Return an empty render array since the warning message is displayed separately
      return [];
    }
    else {
      $script = Markup::create('<script src="https://cdn.userway.org/widget.js" data-account="' . $this->configFactory->get('userway_key') . '"></script>');
    }

    return [
      '#markup' => $script,
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    if ($this->currentUser->hasPermission('view userway widget')) {
      return AccessResult::allowed();
    }
    else {
      return AccessResult::forbidden();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return Cache::mergeContexts(parent::getCacheContexts(), ['route']);
  }

}
